import os
from setuptools import setup


setup(
    name="blackhorse",
    packages=["blackhorse"],
    version="0.1",
    license="MIT",
    description="A beautiful black horse placeholder",
    author="Radu Ghitescu",
    author_email="radu.ghitescu@gmail.com",
    classifiers=[
        "Development Status :: 3 - Alpha", "Intended Audience :: Developers"
    ],
    zip_safe=False,
)
